@@ -708,6 +708,9 @@ gtk_source_language_parse_file (GtkSourceLanguage *language)
 				case GTK_SOURCE_LANGUAGE_VERSION_2_0:
 					success = _gtk_source_language_file_parse_version2 (language, ctx_data);
 					break;
+
+				default:
+					g_assert_not_reached ();
 			}
 
 			if (!success)
